#!/bin/bash
#
# 
#    Ejecter - Safely, easily remove external peripherals
#    Copyright 2008-2011, Federico Pelloni <federico.pelloni@gmail.com>
# 
#    
#    This file is part of Ejecter.
# 
#    Ejecter is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Ejecter is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with Ejecter.  If not, see <http://www.gnu.org/licenses/>.
#   
# 

waf=./waf
target=${HOME}/Progetti/ejecter/test

$waf configure --prefix=$target --debug && $waf $1 && $waf $1 install && $target/bin/ejecter $2

